@@ -1,10 +1,10 @@
 /*
     Drumgrid test using the MIDI Sequencer C++ library
-    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2023, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -17,14 +17,21 @@
 */
 
 #include "drumgridabout.h"
-#include "cmdversion.h"
 
 About::About(QWidget *parent)
     : QDialog(parent)
 {
     ui.setupUi(this);
     QString aboutText = ui.AboutTextView->toHtml();
-    aboutText.replace("%VERSION%", PGM_VERSION);
+    QString strver(QT_STRINGIFY(VERSION));
+#ifdef REVISION
+    strver.append("<br/>");
+    strver.append(tr("Revision"));
+    strver.append("&nbsp;");
+    strver.append(QT_STRINGIFY(REVISION));
+#endif
+    aboutText.replace("%VERSION%", strver);
+    aboutText.replace("%QT_VERSION%", qVersion());
     ui.AboutTextView->setHtml(aboutText);
 }
 
