@@ -1,6 +1,6 @@
 ﻿/*
  Virtual Piano test using the MIDI Sequencer C++ library
- Copyright (C) 2006-2022 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+ Copyright (C) 2006-2023 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -19,6 +19,11 @@
 #include "vpianosettings.h"
 #include <QDir>
 #include <QFileInfo>
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
+    #include <QTouchDevice>
+#else
+    #include <QInputDevice>
+#endif
 #include <drumstick/settingsfactory.h>
 
 using namespace drumstick::rt;
@@ -108,6 +113,33 @@ void VPianoSettings::internalRead(QSettings &settings)
     m_advanced = settings.value("advanced", false).toBool();
     settings.endGroup();
 
+    bool touchInputEnabled = false;
+    bool mouseInputEnabled = true;
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
+    const QList<const QTouchDevice*> devs = QTouchDevice::devices();
+    for(const QTouchDevice *dev : devs) {
+        if (dev->type() == QTouchDevice::TouchScreen) {
+            /*qDebug() << "platform:" << qApp->platformName()
+                     << "desktop:" << qgetenv("XDG_SESSION_DESKTOP")
+                     << "touch device:" << dev;*/
+            touchInputEnabled = true;
+            mouseInputEnabled = !dev->capabilities().testFlag(QTouchDevice::MouseEmulation);
+            break;
+        }
+    }
+#else
+    foreach(const QInputDevice *dev, QInputDevice::devices()) {
+        if (dev->type() == QInputDevice::DeviceType::TouchScreen) {
+            /*qDebug() << "platform:" << qApp->platformName()
+                     << "desktop:" << qgetenv("XDG_SESSION_DESKTOP")
+                     << "touch device:" << dev;*/
+            touchInputEnabled = true;
+            mouseInputEnabled = !dev->capabilities().testFlag(QInputDevice::Capability::MouseEmulation);
+            break;
+        }
+    }
+#endif
+
     settings.beginGroup("Preferences");
     setInChannel(settings.value("inputChannel", 0).toInt());
     setOutChannel(settings.value("outputChannel", 0).toInt());
@@ -118,12 +150,17 @@ void VPianoSettings::internalRead(QSettings &settings)
     setBaseOctave(settings.value("baseOctave", 1).toInt());
     setNumKeys(settings.value("numKeys", 88).toInt());
     setStartingKey(settings.value("startingKey", 9).toInt());
+    setRawKeyboard(settings.value("raw_keyboard", false).toBool());
+    setKeyboardInput(settings.value("keyboard_input", true).toBool());
+    setMouseInput(settings.value("mouse_input", mouseInputEnabled).toBool());
+    setTouchScreenInput(settings.value("touchscreen_input", touchInputEnabled).toBool());
+    setOctaveSubscript(settings.value("octave_subscript", true).toBool());
     settings.endGroup();
 
     settings.beginGroup("TextSettings");
-    QFont f = QGuiApplication::font();
-    f.setPointSize(50);
-    if (f.fromString(settings.value("namesFont", f.toString()).toString())) {
+    QString defaultFont = QGuiApplication::font().family() + ",50";
+    QFont f;
+    if (f.fromString(settings.value("namesFont", defaultFont).toString())) {
         setNamesFont(f);
     }
     setNamesOrientation(static_cast<LabelOrientation>(settings.value("namesOrientation", HorizontalOrientation).toInt()));
@@ -168,10 +205,15 @@ void VPianoSettings::internalSave(QSettings &settings)
     settings.setValue("baseOctave", m_baseOctave);
     settings.setValue("numKeys", m_numKeys);
     settings.setValue("startingKey", m_startingKey);
+    settings.setValue("raw_keyboard", m_rawKeyboard);
+    settings.setValue("keyboard_input", m_keyboardInput);
+    settings.setValue("mouse_input", m_mouseInput);
+    settings.setValue("touchscreen_input", m_touchScreenInput);
+    settings.setValue("octave_subscript", m_octaveSubscript);
     settings.endGroup();
 
     settings.beginGroup("TextSettings");
-    settings.setValue("namesFont", m_namesFont.toString());
+    settings.setValue("namesFont", fontString(m_namesFont));
     settings.setValue("namesOrientation", m_namesOrientation);
     settings.setValue("namesVisibility", m_namesVisibility);
     settings.setValue("namesAlteration", m_namesAlteration);
@@ -185,6 +227,61 @@ void VPianoSettings::internalSave(QSettings &settings)
     settings.sync();
 }
 
+QString VPianoSettings::fontString(const QFont &f) const
+{
+    return QString("%1,%2").arg(f.family()).arg(f.pointSize());
+}
+
+bool VPianoSettings::octaveSubscript() const
+{
+    return m_octaveSubscript;
+}
+
+void VPianoSettings::setOctaveSubscript(bool newOctaveSubscript)
+{
+    m_octaveSubscript = newOctaveSubscript;
+}
+
+bool VPianoSettings::touchScreenInput() const
+{
+    return m_touchScreenInput;
+}
+
+void VPianoSettings::setTouchScreenInput(bool newTouchScreenInput)
+{
+    m_touchScreenInput = newTouchScreenInput;
+}
+
+bool VPianoSettings::mouseInput() const
+{
+    return m_mouseInput;
+}
+
+void VPianoSettings::setMouseInput(bool newMouseInput)
+{
+    m_mouseInput = newMouseInput;
+}
+
+bool VPianoSettings::keyboardInput() const
+{
+    return m_keyboardInput;
+}
+
+void VPianoSettings::setKeyboardInput(bool newKeyboardInput)
+{
+    m_keyboardInput = newKeyboardInput;
+}
+
+bool VPianoSettings::rawKeyboard() const
+{
+    return m_rawKeyboard;
+}
+
+void VPianoSettings::setRawKeyboard(bool newRawKeyboard)
+{
+    m_rawKeyboard = newRawKeyboard;
+}
+
 bool VPianoSettings::invertedKeys() const
 {
     return m_invertedKeys;
